@@ -19,7 +19,7 @@ from flask import Flask, Response, request, render_template, redirect, jsonify a
 from six.moves import range as xrange
 from werkzeug.datastructures import WWWAuthenticate, MultiDict
 from werkzeug.http import http_date
-from werkzeug.wrappers import BaseResponse
+from werkzeug.wrappers import Response
 from werkzeug.http import parse_authorization_header
 from raven.contrib.flask import Sentry
 
@@ -48,9 +48,6 @@ def jsonify(*args, **kwargs):
     return response
 
 # Prevent WSGI from correcting the casing of the Location header
-# and forcing it to be absolute. This moved from BaseResponse to
-# Response in werkzeug 2.0.0, so we set both to be safe.
-BaseResponse.autocorrect_location_header = False
 Response.autocorrect_location_header = False
 
 # Find the correct template folder when running from a different location
